@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import os
 import sys
+from argparse import Namespace
 from ast import literal_eval
 from textwrap import dedent
 
@@ -9,6 +10,39 @@ from virtualenv.activation import PythonActivator
 from virtualenv.info import IS_WIN
 
 
+def test_python_activator_generates_pkg_config_path(tmp_path):
+    """Test that activate_this.py sets PKG_CONFIG_PATH."""
+
+    class MockInterpreter:
+        tcl_lib = None
+        tk_lib = None
+
+    class MockCreator:
+        def __init__(self, dest):
+            self.dest = dest
+            self.bin_dir = dest / ("Scripts" if IS_WIN else "bin")
+            self.bin_dir.mkdir(parents=True)
+            self.libs = [dest / "Lib" / "site-packages"]
+            self.env_name = "test-env"
+            self.interpreter = MockInterpreter()
+            self.pyenv_cfg = {}
+
+    creator = MockCreator(tmp_path)
+    options = Namespace(prompt=None)
+    activator = PythonActivator(options)
+
+    # Generate the activation script
+    activator.generate(creator)
+
+    # Read the generated script
+    content = (creator.bin_dir / "activate_this.py").read_text(encoding="utf-8")
+
+    # Verify PKG_CONFIG_PATH is set
+    assert "PKG_CONFIG_PATH" in content
+    assert "pkg_config_path" in content
+    assert 'os.path.join(base, "lib", "pkgconfig")' in content
+
+
 def test_python(raise_on_non_source_class, activation_tester):
     class Python(raise_on_non_source_class):
         def __init__(self, session) -> None:
@@ -18,7 +52,7 @@ def test_python(raise_on_non_source_class, activation_tester):
                 sys.executable,
                 activate_script="activate_this.py",
                 extension="py",
-                non_source_fail_message="You must use exec(open(this_file).read(), {'__file__': this_file}))",
+                non_source_fail_message="You must use import runpy; runpy.run_path(this_file)",
             )
             self.unix_line_ending = not IS_WIN
 
@@ -36,6 +70,7 @@ def test_python(raise_on_non_source_class, activation_tester):
             import os
             import sys
             import platform
+            import runpy
 
             def print_r(value):
                 print(repr(value))
@@ -47,10 +82,7 @@ def test_python(raise_on_non_source_class, activation_tester):
 
             file_at = {str(activate_script)!r}
             # CPython 2 requires non-ascii path open to be unicode
-            with open(file_at, "r", encoding='utf-8') as file_handler:
-                content = file_handler.read()
-            exec(content, {{"__file__": file_at}})
-
+            runpy.run_path(file_at)
             print_r(os.environ.get("VIRTUAL_ENV"))
             print_r(os.environ.get("VIRTUAL_ENV_PROMPT"))
             print_r(os.environ.get("PATH").split(os.pathsep))
