@@ -6,31 +6,39 @@ from pathlib import Path
 
 import pytest
 
-from tests.unit.discovery.util import MockAppData, MockCache
 from virtualenv.discovery.py_info import EXTENSIONS, PythonInfo
 from virtualenv.info import IS_WIN, fs_is_case_sensitive, fs_supports_symlink
 
-CURRENT = PythonInfo.current(MockAppData(), MockCache())
+CURRENT = PythonInfo.current()
 
 
-def test_discover_empty_folder(tmp_path):
-    app_data, cache = MockAppData(), MockCache()
+def test_discover_empty_folder(tmp_path, session_app_data):
     with pytest.raises(RuntimeError):
-        CURRENT.discover_exe(app_data, prefix=str(tmp_path), cache=cache)
+        CURRENT.discover_exe(session_app_data, prefix=str(tmp_path))
 
 
-BASE = (CURRENT.install_path("scripts"), ".")
+def _discover_base_folders() -> tuple[str, ...]:
+    exe_dir = os.path.dirname(CURRENT.executable)
+    folders: dict[str, None] = {}
+    if exe_dir.startswith(CURRENT.prefix):
+        relative = exe_dir[len(CURRENT.prefix) :].lstrip(os.sep)
+        if relative:
+            folders[relative] = None
+    folders["."] = None
+    return tuple(folders)
+
+
+BASE = _discover_base_folders()
 
 
 @pytest.mark.skipif(not fs_supports_symlink(), reason="symlink is not supported")
-@pytest.mark.parametrize("suffix", sorted({".exe", ".cmd", ""} & set(EXTENSIONS) if IS_WIN else [""]))
+@pytest.mark.parametrize("suffix", sorted({".exe", ""} & set(EXTENSIONS) if IS_WIN else [""]))
 @pytest.mark.parametrize("into", BASE)
 @pytest.mark.parametrize("arch", [CURRENT.architecture, ""])
 @pytest.mark.parametrize("version", [".".join(str(i) for i in CURRENT.version_info[0:i]) for i in range(3, 0, -1)])
 @pytest.mark.parametrize("impl", [CURRENT.implementation, "python"])
-def test_discover_ok(tmp_path, suffix, impl, version, arch, into, caplog):  # noqa: PLR0913
+def test_discover_ok(tmp_path, suffix, impl, version, arch, into, caplog, session_app_data):  # noqa: PLR0913
     caplog.set_level(logging.DEBUG)
-    app_data, cache = MockAppData(), MockCache()
     folder = tmp_path / into
     folder.mkdir(parents=True, exist_ok=True)
     name = f"{impl}{version}{'t' if CURRENT.free_threaded else ''}"
@@ -43,7 +51,7 @@ def test_discover_ok(tmp_path, suffix, impl, version, arch, into, caplog):  # no
     if pyvenv.exists():
         (folder / pyvenv.name).write_text(pyvenv.read_text(encoding="utf-8"), encoding="utf-8")
     inside_folder = str(tmp_path)
-    base = CURRENT.discover_exe(app_data, inside_folder, cache=cache)
+    base = CURRENT.discover_exe(session_app_data, inside_folder)
     found = base.executable
     dest_str = str(dest)
     if not fs_is_case_sensitive():
@@ -56,4 +64,4 @@ def test_discover_ok(tmp_path, suffix, impl, version, arch, into, caplog):  # no
     dest.rename(dest.parent / (dest.name + "-1"))
     CURRENT._cache_exe_discovery.clear()  # noqa: SLF001
     with pytest.raises(RuntimeError):
-        CURRENT.discover_exe(app_data, inside_folder, cache=cache)
+        CURRENT.discover_exe(session_app_data, inside_folder)
